@@ -2,7 +2,9 @@
 use strict;
 use warnings;
 
+my $dev = shift || die("Specify network interface\n");
+
 use Net::Frame::Device;
 
-my $d = Net::Frame::Device->new(dev => 'lo');
+my $d = Net::Frame::Device->new(dev => $dev);
 print $d->cgDumper."\n";
